import logging
import scipy.stats as sps
import math
from typing import Literal

from .analytic import Analytic

logger = logging.getLogger(__name__)

class Logistic(Analytic):
    t: Literal['logistic'] = 'logistic'
    loc: float = 0
    scale: float = 1

    def __post_init__(self):
        self._rv = sps.logistic(
                self.loc,
                self.scale
            )
